summaryrefslogtreecommitdiff
path: root/src/omap_driver.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/omap_driver.h')
-rw-r--r--src/omap_driver.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/omap_driver.h b/src/omap_driver.h
index 7837e48..68af94e 100644
--- a/src/omap_driver.h
+++ b/src/omap_driver.h
@@ -160,8 +160,8 @@ typedef struct _OMAPRec
XF86VideoAdaptorPtr textureAdaptor;
- /** Flips we are waiting for: */
- int pending_flips;
+ /** Swaps we are waiting for: */
+ int pending_swaps;
} OMAPRec, *OMAPPtr;